#!/bin/bash
#------------------------------------------------------------------------------
# test_sc_with_root.sh: Scrpt for testing snapclone.sh.

# Requires Perforce Sample Depot configured with the Helix Installer default,
# with p4d server running locally with P4PORT ssl:1999, and passwords for
# users quinn, earl, and bruno all set to: F@stSCM!
#
# This scripts sets up three DVCS repos, each copied from a template
# with rsync, simulating use of a NetApp snapshot to clone the user
# workspace.

# The user must have enough sudo access to do a 'chown -R' command on
# the .p4root directory after the copy.  This is not simulated in this
# version
set -u

function msg () { echo -e "$*"; }
function bail () { msg "Error: $1"; exit ${2:-1}; }
function cmd () { msg "Executing: $*"; $*; return $?; }
function usage () { prog=${0##/*}; msg "Usage:\n\t$prog 2>&1 | tee ${prog/.sh/.log}\n"; exit 1; }
H1="=============================================================================="
H2="------------------------------------------------------------------------------"

declare Version=1.1.1
declare -a TestUsers
declare User
declare -i i=0

TestUsers[0]=quinn
TestUsers[1]=earl
TestUsers[2]=bruno

#------------------------------------------------------------------------------
# Environment control, including environment hijacking defense.
source /p4/common/bin/p4_vars 1
export P4ENVIRO=/dev/null/.p4enviro
export P4CONFIG=${P4CONFIG:-.p4config}
export P4CONFIG=${P4CONFIG##*/}
export P4TICKETS=/netapp/p4/ws/.p4tickets.tsc
export P4TRUST=/netapp/tmp/u/.p4trust.tsc

[[ $* == *"-h"* ]] && usage

ThisUser=$(whoami)

if [[ $ThisUser == "perforce" ]]; then
   exec sudo su root -c "$0 $*"
elif [[ $ThisUser != "root" ]]; then
   bail "Run as root (or perforce)."
fi

msg "Verified: Running as: $ThisUser."

TestPassword='F@stSCM!'

while [[ $i -lt ${#TestUsers[@]} ]]; do
   User=${TestUsers[$i]}

   msg "Executing as $User: snapclone.sh -u $User -p jam -F -P 'F@stSCM!'"
   su - $User -c "snapclone.sh -u $User -p jam -F -P 'F@stSCM!'"

   i=$((i+1))
done
